@@ -96,7 +96,7 @@ struct Token<'line> {
     text: &'line str,
 }
 
-impl<'line> Token<'line> {
+impl Token<'_> {
     fn chomp(&mut self) {
         if self.text.ends_with('\n') {
             self.text = &self.text[..self.text.len() - 1];
@@ -1010,8 +1010,9 @@ impl<'main, W> SyntectPrinter<'main, W> {
                 "automount" | "device" | "dnssd" | "link" | "mount" | "netdev" | "network"
                 | "nspawn" | "path" | "service" | "scope" | "slice" | "socket" | "swap"
                 | "target" | "timer" => Some("INI"),
-                "sarif" | "jsonl" => Some("JSON"),
+                "sarif" | "jsonl" | "geojson" | "jsonc" | "jsonld" => Some("JSON"),
                 "ron" => Some("Rust"),
+                "mkd" => Some("Markdown"),
                 _ => None,
             })
             // Find from file name
@@ -1062,6 +1063,22 @@ impl<'main, W> SyntectPrinter<'main, W> {
                 if path.starts_with("/var/spool/mail/") || path.starts_with("/var/mail/") {
                     return Some("Email");
                 }
+                #[cfg(not(windows))]
+                if path.starts_with("/etc/wireguard/") && path.ends_with(".conf") {
+                    return Some("INI");
+                }
+                #[cfg(not(windows))]
+                if path == "/etc/pacman.conf" {
+                    return Some("INI");
+                }
+                #[cfg(not(windows))]
+                if path.contains("/containers/") && path.ends_with(".conf") {
+                    return Some("TOML");
+                }
+                #[cfg(not(windows))]
+                if path.starts_with("/etc/kubernetes/") && path.ends_with(".conf") {
+                    return Some("YAML");
+                }
                 None
             });
 
@@ -1076,7 +1093,7 @@ impl<'main, W> SyntectPrinter<'main, W> {
     }
 }
 
-impl<'main, W: WriteOnLocked> Printer for SyntectPrinter<'main, W> {
+impl<W: WriteOnLocked> Printer for SyntectPrinter<'_, W> {
     fn print(&self, file: File) -> Result<()> {
         if file.chunks.is_empty() || file.line_matches.is_empty() {
             return Ok(());
@@ -1100,7 +1117,7 @@ impl<'main, W: WriteOnLocked> Printer for SyntectPrinter<'main, W> {
 mod tests {
     use super::*;
     use crate::chunk::{File, LineMatch};
-    use lazy_static::lazy_static;
+    use once_cell::sync::Lazy;
     use std::cell::{RefCell, RefMut};
     use std::fmt;
     use std::fs;
@@ -1108,12 +1125,10 @@ mod tests {
     use std::path::PathBuf;
     use std::str;
 
-    lazy_static! {
-        static ref ASSETS: SyntectAssets = SyntectAssets::load(None).unwrap();
-    }
+    static ASSETS: Lazy<SyntectAssets> = Lazy::new(|| SyntectAssets::load(None).unwrap());
 
     struct DummyStdoutLock<'a>(RefMut<'a, Vec<u8>>);
-    impl<'a> Write for DummyStdoutLock<'a> {
+    impl Write for DummyStdoutLock<'_> {
         fn write(&mut self, buf: &[u8]) -> io::Result<usize> {
             self.0.write(buf)
         }
